tietools.iterate_topmost_tie_chains_and_components_forward_in_expr
==================================================================

.. autofunction:: abjad.tools.tietools.iterate_topmost_tie_chains_and_components_forward_in_expr.iterate_topmost_tie_chains_and_components_forward_in_expr
